package com.xinelu.manage.mapper.coupon;

import com.xinelu.manage.domain.coupon.Coupon;

import java.util.List;


/**
 * 优惠券信息Mapper接口
 *
 * @author xinyilu
 * @date 2023-02-23
 */
public interface CouponMapper {
    /**
     * 查询优惠券信息
     *
     * @param id 优惠券信息主键
     * @return 优惠券信息
     */
    Coupon selectCouponById(Long id);

    /**
     * 查询优惠券信息列表
     *
     * @param coupon 优惠券信息
     * @return 优惠券信息集合
     */
    List<Coupon> selectCouponList(Coupon coupon);

    /**
     * 新增优惠券信息
     *
     * @param coupon 优惠券信息
     * @return 结果
     */
    int insertCoupon(Coupon coupon);

    /**
     * 修改优惠券信息
     *
     * @param coupon 优惠券信息
     * @return 结果
     */
    int updateCoupon(Coupon coupon);

    /**
     * 删除优惠券信息
     *
     * @param id 优惠券信息主键
     * @return 结果
     */
    int deleteCouponById(Long id);

    /**
     * 批量删除优惠券信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCouponByIds(Long[] ids);

    /**
     * 查询优惠券信息(通过名称查询优惠券信息)
     *
     * @param couponTitle 优惠券信息主键
     * @return 优惠券信息
     */
    int selectCouponByTitle(String couponTitle);

}
